@@ -731,16 +731,6 @@ class TestHeaders:
         h[:] = [(k, v) for k, v in h if k.startswith("X-")]
         assert list(h) == [("X-Foo-Poo", "bleh"), ("X-Forwarded-For", "192.168.0.123")]
 
-    def test_bytes_operations(self):
-        h = self.storage_class()
-        h.set("X-Foo-Poo", "bleh")
-        h.set("X-Whoops", b"\xff")
-        h.set(b"X-Bytes", b"something")
-
-        assert h.get("x-foo-poo", as_bytes=True) == b"bleh"
-        assert h.get("x-whoops", as_bytes=True) == b"\xff"
-        assert h.get("x-bytes") == "something"
-
     def test_extend(self):
         h = self.storage_class([("a", "0"), ("b", "1"), ("c", "2")])
         h.extend(ds.Headers([("a", "3"), ("a", "4")]))
@@ -791,13 +781,6 @@ class TestHeaders:
             assert key == "Key"
             assert value == "Value"
 
-    def test_to_wsgi_list_bytes(self):
-        h = self.storage_class()
-        h.set(b"Key", b"Value")
-        for key, value in h.to_wsgi_list():
-            assert key == "Key"
-            assert value == "Value"
-
     def test_equality(self):
         # test equality, given keys are case insensitive
         h1 = self.storage_class()
@@ -853,13 +836,6 @@ class TestEnvironHeaders:
         assert headers["Foo"] == "\xe2\x9c\x93"
         assert next(iter(headers)) == ("Foo", "\xe2\x9c\x93")
 
-    def test_bytes_operations(self):
-        foo_val = "\xff"
-        h = self.storage_class({"HTTP_X_FOO": foo_val})
-
-        assert h.get("x-foo", as_bytes=True) == b"\xff"
-        assert h.get("x-foo") == "\xff"
-
 
 class TestHeaderSet:
     storage_class = ds.HeaderSet
@@ -1177,6 +1153,8 @@ class TestFileStorage:
         for name in ("fileno", "writable", "readable", "seekable"):
             assert hasattr(file_storage, name)
 
+        file_storage.close()
+
     def test_save_to_pathlib_dst(self, tmp_path):
         src = tmp_path / "src.txt"
         src.write_text("test")
